@@ -55,8 +55,12 @@ fn main() {
     // Windows-style paths (those starting with C:\), but it chokes on those.
     // For that reason we build up a shell script with paths converted to
     // posix versions hopefully...
+    //
+    // Also apparently the buildbots choke unless we manually set LD, who knows
+    // why?!
     run(Command::new("sh")
                 .env("CFLAGS", cflags)
+                .env("LD", which("ld").unwrap())
                 .cwd(&dst.join("build"))
                 .arg("-c")
                 .arg(format!("{} {}", root.join("configure").display(),
@@ -86,7 +90,7 @@ fn main() {
         let root = root.join("include");
         let dst = dst.join("include");
         for file in fs::walk_dir(&root).unwrap() {
-            if fs::stat(&file).unwrap().kind != io::TypeFile { continue }
+            if fs::stat(&file).unwrap().kind != io::FileType::RegularFile { continue }
 
             let part = file.path_relative_from(&root).unwrap();
             let dst = dst.join(part);
@@ -116,3 +120,9 @@ fn run(cmd: &mut Command) {
                .success());
 
 }
+
+fn which(cmd: &str) -> Option<Path> {
+    let cmd = format!("{}{}", cmd, os::consts::EXE_SUFFIX);
+    let paths = os::split_paths(os::getenv("PATH").unwrap());
+    paths.iter().map(|p| p.join(&cmd)).find(|p| p.exists())
+}
